# This file enables a Fatdog64-specific alternative to xdg-open.
# IT IS AN OPT-IN CONFIGURATION FILE. EDIT TO APPLY CHANGES.
#
# BACKGROUND
# ==========
# The Desktop Environment (DE) uses xdg-open to launch the appropriate
# application when a user clicks a data file icon, relying on the standard XDG
# MIME type database. ROX-Filer bypasses xdg-open and uses its own ROX
# MIME-type database, separate from XDG's, which can cause desynchronization
# and inconsistent application launches depending on context.
#
# Fatdog64 resolves this by synchronizing the two databases, prioritizing
# ROX's database, via the script /usr/bin/fatdog-sync-mime.sh.
#
# USAGE
# =====
# Enable EITHER (but not both) of these options:
#   1) Uncomment the XDG_DEFAULT_DESKTOP line below (recommended), OR
#   2) Create a symbolic link /usr/local/bin/xdg-open -> /usr/bin/rox-open.
#
# Note: If you use a non-ROX file manager most of the time, or a full
# Desktop Environment (DE) instead of Fatdog's ROX-based DE, you probably
# should not enable any option at all.
#
# EFFECTS
# -------
#   1) The standard xdg-open will use rox-open to launch applications.
#   2) rox-open will fully replace the standard xdg-open.
#
# Both options are safe for your data.
#
# Enable either option when you:
#   - Install packages with new data files lacking proper MIME-type setup.
#   - Install packages that configure MIME types without rebooting.
#   - Occasionally use a non-ROX-Filer file manager that opens files differently.
#
# Note: If ROX-Filer opens files incorrectly before enabling either option,
# adjust ROX-Filer's MIME types directly; this opt-in file will not help.
#
# TO ENABLE ONE OF THE OPTIONS
# ============================
#
# Option 1: Uncomment next line:
# [ -x /usr/local/bin/xdg-open ] || export XDG_DEFAULT_DESKTOP=X-Generic
#
# Option 1 makes the standard xdg-open use Fatdog's
# mimetype and mimeopen commands to eventually calling
# rox-open. This option is slower than the next option.
#
# Option 2: Uncomment next line:
# ln -sf /usr/bin/rox-open /usr/local/bin/xdg-open
#
# IMPORTANT: Ensure your PATH lists /usr/local/bin before /usr/bin.
# This is the default in Fatdog64 and most Linux systems.
# Do not use option 2 otherwise.
#
# Option 2 replaces the standard xdg-open run with a call to rox-open
# via the local symbolic link, bypassing the standard xdg-open
# altogether, and launching rox-open more efficiently than option 1.
#
# ADDITIONAL SETTINGS
# ===================
# Environment variables for rox-open (defaults shown).
# Change only if you understand how they impact rox-open:
#
# export ROX_OPEN_FALLBACK_CMD='/usr/bin/xdg-open'
# export ROX_OPEN_HTTPS='www[.][^.]+[.](com|net|org|au|uk)'  # or 'off'
# export ROX_OPEN_QUIET=''
#
# Also, /etc/defaultprograms or $HOME/.fatdog/defaultprograms sets ROX-Filer's
# location (DEF_ROX).
